"""


Object Greasepencil Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. _rna-enum-object-greasepencil-modifier-type-items:

**Modify**

:GP_TEXTURE:      
  Texture Mapping.

  Change stroke uv texture values.

:GP_TIME:         
  Time Offset.

  Offset keyframes.

:GP_WEIGHT_ANGLE: 
  Vertex Weight Angle.

  Generate Vertex Weights base on stroke angle.

:GP_WEIGHT_PROXIMITY:
  Vertex Weight Proximity.

  Generate Vertex Weights base on distance to object.

**Generate**

:GP_ARRAY:        
  Array.

  Create array of duplicate instances.

:GP_BUILD:        
  Build.

  Create duplication of strokes.

:GP_DASH:         
  Dot Dash.

  Generate dot-dash styled strokes.

:GP_ENVELOPE:     
  Envelope.

  Create an envelope shape.

:GP_LENGTH:       
  Length.

  Extend or shrink strokes.

:GP_LINEART:      
  Line Art.

  Generate line art strokes from selected source.

:GP_MIRROR:       
  Mirror.

  Duplicate strokes like a mirror.

:GP_MULTIPLY:     
  Multiple Strokes.

  Produce multiple strokes along one stroke.

:GP_OUTLINE:      
  Outline.

  Convert stroke to perimeter.

:GP_SIMPLIFY:     
  Simplify.

  Simplify stroke reducing number of points.

:GP_SUBDIV:       
  Subdivide.

  Subdivide stroke adding more control points.

**Deform**

:GP_ARMATURE:     
  Armature.

  Deform stroke points using armature object.

:GP_HOOK:         
  Hook.

  Deform stroke points using objects.

:GP_LATTICE:      
  Lattice.

  Deform strokes using lattice.

:GP_NOISE:        
  Noise.

  Add noise to strokes.

:GP_OFFSET:       
  Offset.

  Change stroke location, rotation or scale.

:SHRINKWRAP:      
  Shrinkwrap.

  Project the shape onto another object.

:GP_SMOOTH:       
  Smooth.

  Smooth stroke.

:GP_THICK:        
  Thickness.

  Change stroke thickness.

**Color**

:GP_COLOR:        
  Hue/Saturation.

  Apply changes to stroke colors.

:GP_OPACITY:      
  Opacity.

  Opacity of the strokes.

:GP_TINT:         
  Tint.

  Tint strokes with new color.

"""

import typing
