"""


Shrinkwrap Type Items
^^^^^^^^^^^^^^^^^^^^^

:NEAREST_SURFACEPOINT:
  Nearest Surface Point.

  Shrink the mesh to the nearest target surface.

:PROJECT:         
  Project.

  Shrink the mesh to the nearest target surface along a given axis.

:NEAREST_VERTEX:  
  Nearest Vertex.

  Shrink the mesh to the nearest target vertex.

:TARGET_PROJECT:  
  Target Normal Project.

  Shrink the mesh to the nearest target surface along the interpolated vertex normals of the target.

.. _rna-enum-shrinkwrap-type-items:

"""

import typing
