"""


Property Flag Items
^^^^^^^^^^^^^^^^^^^

:HIDDEN:          
  Hidden.

:SKIP_SAVE:       
  Skip Save.

:ANIMATABLE:      
  Animatable.

:LIBRARY_EDITABLE:
  Library Editable.

:PROPORTIONAL:    
  Adjust values proportionally to each other.

:TEXTEDIT_UPDATE: 
  Update on every keystroke in textedit 'mode'.

:OUTPUT_PATH:     
  Output Path.

.. _rna-enum-property-flag-items:

"""

import typing
