"""


Brush Gpencil Vertex Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:BLUR:            
  Blur.

:AVERAGE:         
  Average.

:SMEAR:           
  Smear.

:REPLACE:         
  Replace.

.. _rna-enum-brush-gpencil-vertex-types-items:

"""

import typing
