"""


Object Axis Items
^^^^^^^^^^^^^^^^^

:POS_X:           
  +X.

:POS_Y:           
  +Y.

:POS_Z:           
  +Z.

:NEG_X:           
  -X.

:NEG_Y:           
  -Y.

:NEG_Z:           
  -Z.

.. _rna-enum-object-axis-items:

"""

import typing
