"""


Bake Pass Type Items
^^^^^^^^^^^^^^^^^^^^

:COMBINED:        
  Combined.

:AO:              
  Ambient Occlusion.

:SHADOW:          
  Shadow.

:POSITION:        
  Position.

:NORMAL:          
  Normal.

:UV:              
  UV.

:ROUGHNESS:       
  ROUGHNESS.

:EMIT:            
  Emit.

:ENVIRONMENT:     
  Environment.

:DIFFUSE:         
  Diffuse.

:GLOSSY:          
  Glossy.

:TRANSMISSION:    
  Transmission.

.. _rna-enum-bake-pass-type-items:

"""

import typing
