"""


Transform Orientation Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:GLOBAL:          
  Global.

  Align the transformation axes to world space.

:LOCAL:           
  Local.

  Align the transformation axes to the selected objects' local space.

:NORMAL:          
  Normal.

  Align the transformation axes to average normal of selected elements (bone Y axis for pose mode).

:GIMBAL:          
  Gimbal.

  Align each axis to the Euler rotation axis as used for input.

:VIEW:            
  View.

  Align the transformation axes to the window.

:CURSOR:          
  Cursor.

  Align the transformation axes to the 3D cursor.

.. _rna-enum-transform-orientation-items:

"""

import typing
