"""


Image Type Items
^^^^^^^^^^^^^^^^

.. _rna-enum-image-type-items:

**Image**

:BMP:             
  BMP.

  Output image in bitmap format.

:IRIS:            
  Iris.

  Output image in SGI IRIS format.

:PNG:             
  PNG.

  Output image in PNG format.

:JPEG:            
  JPEG.

  Output image in JPEG format.

:JPEG2000:        
  JPEG 2000.

  Output image in JPEG 2000 format.

:TARGA:           
  Targa.

  Output image in Targa format.

:TARGA_RAW:       
  Targa Raw.

  Output image in uncompressed Targa format.

======================================================================

:CINEON:          
  Cineon.

  Output image in Cineon format.

:DPX:             
  DPX.

  Output image in DPX format.

:OPEN_EXR_MULTILAYER:
  OpenEXR MultiLayer.

  Output image in multilayer OpenEXR format.

:OPEN_EXR:        
  OpenEXR.

  Output image in OpenEXR format.

:HDR:             
  Radiance HDR.

  Output image in Radiance HDR format.

:TIFF:            
  TIFF.

  Output image in TIFF format.

**Movie**

:AVI_JPEG:        
  AVI JPEG.

  Output video in AVI JPEG format.

:AVI_RAW:         
  AVI Raw.

  Output video in AVI Raw format.

:FFMPEG:          
  FFmpeg Video.

  The most versatile way to output video files.

"""

import typing
