"""


Brush Image Tool Items
^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

:SOFTEN:          
  Soften.

:SMEAR:           
  Smear.

:CLONE:           
  Clone.

:FILL:            
  Fill.

:MASK:            
  Mask.

.. _rna-enum-brush-image-tool-items:

"""

import typing
