"""


Id Type Items
^^^^^^^^^^^^^

:ACTION:          
  Action.

:ARMATURE:        
  Armature.

:BRUSH:           
  Brush.

:CACHEFILE:       
  Cache File.

:CAMERA:          
  Camera.

:COLLECTION:      
  Collection.

:CURVE:           
  Curve.

:CURVES:          
  Curves.

:FONT:            
  Font.

:GREASEPENCIL:    
  Grease Pencil.

:IMAGE:           
  Image.

:KEY:             
  Key.

:LATTICE:         
  Lattice.

:LIBRARY:         
  Library.

:LIGHT:           
  Light.

:LIGHT_PROBE:     
  Light Probe.

:LINESTYLE:       
  Line Style.

:MASK:            
  Mask.

:MATERIAL:        
  Material.

:MESH:            
  Mesh.

:META:            
  Metaball.

:MOVIECLIP:       
  Movie Clip.

:NODETREE:        
  Node Tree.

:OBJECT:          
  Object.

:PAINTCURVE:      
  Paint Curve.

:PALETTE:         
  Palette.

:PARTICLE:        
  Particle.

:POINTCLOUD:      
  Point Cloud.

:SCENE:           
  Scene.

:SIMULATION:      
  Simulation.

:SOUND:           
  Sound.

:SPEAKER:         
  Speaker.

:TEXT:            
  Text.

:TEXTURE:         
  Texture.

:VOLUME:          
  Volume.

:WINDOWMANAGER:   
  Window Manager.

:WORKSPACE:       
  Workspace.

:WORLD:           
  World.

.. _rna-enum-id-type-items:

"""

import typing
