"""


Color Attribute Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:FLOAT_COLOR:     
  Color.

  RGBA color 32-bit floating-point values.

:BYTE_COLOR:      
  Byte Color.

  RGBA color with 8-bit positive integer values.

.. _rna-enum-color-attribute-type-items:

"""

import typing
