"""


Export Anim Operators
*********************

:func:`bvh`

"""

import typing

def bvh(filepath: str = '', check_existing: bool = True, filter_glob: str = '*args.bvh', global_scale: float = 1.0, frame_start: int = 0, frame_end: int = 0, rotate_mode: str = 'NATIVE', root_transform_only: bool = False) -> None:

  """

  Save a BVH motion capture file from an armature

  """

  ...
