"""


Dt Layers Select Dst Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:ACTIVE:          
  Active Layer.

  Affect active data layer of all targets.

:NAME:            
  By Name.

  Match target data layers to affect by name.

:INDEX:           
  By Order.

  Match target data layers to affect by order (indices).

.. _rna-enum-dt-layers-select-dst-items:

"""

import typing
