"""


Rigidbody Constraint Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FIXED:           
  Fixed.

  Glue rigid bodies together.

:POINT:           
  Point.

  Constrain rigid bodies to move around common pivot point.

:HINGE:           
  Hinge.

  Restrict rigid body rotation to one axis.

:SLIDER:          
  Slider.

  Restrict rigid body translation to one axis.

:PISTON:          
  Piston.

  Restrict rigid body translation and rotation to one axis.

:GENERIC:         
  Generic.

  Restrict translation and rotation to specified axes.

:GENERIC_SPRING:  
  Generic Spring.

  Restrict translation and rotation to specified axes with springs.

:MOTOR:           
  Motor.

  Drive rigid body around or along an axis.

.. _rna-enum-rigidbody-constraint-type-items:

"""

import typing
