"""


Attribute Domain Without Corner Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

:CURVE:           
  Spline.

  Attribute on spline.

:INSTANCE:        
  Instance.

  Attribute on instance.

.. _rna-enum-attribute-domain-without-corner-items:

"""

import typing
