"""


Motionpath Bake Location Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:HEADS:           
  Heads.

  Calculate bone paths from heads.

:TAILS:           
  Tails.

  Calculate bone paths from tails.

.. _rna-enum-motionpath-bake-location-items:

"""

import typing
