"""


Subdivision Boundary Smooth Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:PRESERVE_CORNERS:
  Keep Corners.

  Smooth boundaries, but corners are kept sharp.

:ALL:             
  All.

  Smooth boundaries, including corners.

.. _rna-enum-subdivision-boundary-smooth-items:

"""

import typing
