"""


Property Unit Items
^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:LENGTH:          
  Length.

:AREA:            
  Area.

:VOLUME:          
  Volume.

:ROTATION:        
  Rotation.

:TIME:            
  Time (Scene Relative).

:TIME_ABSOLUTE:   
  Time (Absolute).

:VELOCITY:        
  Velocity.

:ACCELERATION:    
  Acceleration.

:MASS:            
  Mass.

:CAMERA:          
  Camera.

:POWER:           
  Power.

:TEMPERATURE:     
  Temperature.

.. _rna-enum-property-unit-items:

"""

import typing
