"""


bpy_extras submodule (bpy_extras.asset_utils)
*********************************************

Helpers for asset management tasks.

:class:`SpaceAssetInfo`

"""

import typing

class SpaceAssetInfo:

  ...
