"""


Property Flag Enum Items
^^^^^^^^^^^^^^^^^^^^^^^^

:HIDDEN:          
  Hidden.

:SKIP_SAVE:       
  Skip Save.

:ANIMATABLE:      
  Animatable.

:LIBRARY_EDITABLE:
  Library Editable.

:ENUM_FLAG:       
  Enum Flag.

.. _rna-enum-property-flag-enum-items:

"""

import typing
