"""


Image Generated Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:BLANK:           
  Blank.

  Generate a blank image.

:UV_GRID:         
  UV Grid.

  Generated grid to test UV mappings.

:COLOR_GRID:      
  Color Grid.

  Generated improved UV grid to test UV mappings.

.. _rna-enum-image-generated-type-items:

"""

import typing
