"""


Linestyle Geometry Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:2D_OFFSET:       
  2D Offset.

:2D_TRANSFORM:    
  2D Transform.

:BACKBONE_STRETCHER:
  Backbone Stretcher.

:BEZIER_CURVE:    
  Bezier Curve.

:BLUEPRINT:       
  Blueprint.

:GUIDING_LINES:   
  Guiding Lines.

:PERLIN_NOISE_1D: 
  Perlin Noise 1D.

:PERLIN_NOISE_2D: 
  Perlin Noise 2D.

:POLYGONIZATION:  
  Polygonization.

:SAMPLING:        
  Sampling.

:SIMPLIFICATION:  
  Simplification.

:SINUS_DISPLACEMENT:
  Sinus Displacement.

:SPATIAL_NOISE:   
  Spatial Noise.

:TIP_REMOVER:     
  Tip Remover.

.. _rna-enum-linestyle-geometry-modifier-type-items:

"""

import typing
